@@ -28,7 +28,6 @@
 
 G_BEGIN_DECLS
 
-GdkPixbuf	*totem_interface_load_pixbuf	(const char *name);
 char		*totem_interface_get_full_path	(const char *name);
 GtkBuilder	*totem_interface_load		(const char *name,
 						 gboolean fatal,
@@ -49,8 +48,6 @@ void		 totem_interface_error_with_link (const char *title,
 						  const char *uri,
 						  const char *label,
 						  GtkWindow *parent);
-void		 totem_interface_set_transient_for (GtkWindow *window,
-						    GtkWindow *parent);
 GtkWidget *	 totem_interface_create_header_button (GtkWidget  *header,
 						       GtkWidget  *button,
 						       const char *icon_name,
